<?PHP
/**
* Docsys Module Class
*
* This class produce the RSS XML Feedfile of the latest docsys entries
*
* @copyright CONTREXX CMS - Astalavista IT Engineering GmbH Thun
* @author Astalavista Development Team <thun@astalvista.ch>
* @module docsys
* @modulegroup modules
* @access public
* @version 1.0.0    
*/


class rssFeed
{
	var $xmlType;
	var $filePath;
	var $fileName = array();
	var $limit;
	var $langId;
	
	var $channelTitle;
	var $channelLink;
	var $channelDescription;
	var $channelLanguage;
	var $channelCopyright;
	var $channelGenerator;
	var $channelWebMaster;
	var $itemLink;
 
	
	/**
    * Constructor
    *
	* @global	array		$_CONFIG
	* @global	string		$db
    */
	function rssFeed()
	{
		global $_CONFIG, $objInit, $db;
		
		$this->langId=$objInit->userFrontendLangId; 

		$db->query("SELECT lang FROM ".DBPREFIX."languages WHERE id='$this->langId'");		
		$db->next_record();	
		
		$this->xmlType = "headlines";
		$this->filePath = ASCMS_FEED_PATH;
		$this->channelLink = ASCMS_PROTOCOL."://".$_SERVER['SERVER_NAME'];
		$this->channelCopyright = ASCMS_PROTOCOL."://".$_SERVER['SERVER_NAME'];
		$this->channelGenerator = $_CONFIG['coreCmsName'];
		$this->channelWebMaster = $_CONFIG['coreAdminEmail'];		
		$this->channelLanguage  = $db->f('lang');
		$this->itemLink = ASCMS_PROTOCOL."://".$_SERVER['SERVER_NAME']."/?section=docsys&amp;cmd=details&amp;id=";
		$this->fileName[1] = 'docsys_headlines_'.$db->f('lang').'.xml';
		$this->fileName[2] = 'docsys_'.$db->f('lang').'.xml';	
		
		$this->limit=20;
		if($this->limit<1 OR $this->limit>100){
			$this->limit=10;
		}	
	}
	
	
	/**
    * checks the file and folder permissions
    *   
	* @return   boolean    
    */
	function checkPermissions()
	{
		if(is_writeable(ASCMS_DOCUMENT_ROOT.$this->filePath) AND is_dir(ASCMS_DOCUMENT_ROOT.$this->filePath)){
			return true;
		}
		else{
			return false;
		}
	}
	
	/**
    * createXML: parse out the XML
    *
	* @global   array     	$_LANGID 
	* @global	string		$db
    */	
    function createXML()
    {
    	global $_LANGID,$db;
    	
    	if ($this->checkPermissions()){
		    $xmlOutput .= "<?xml version=\"1.0\" encoding=\"ISO-8859-1\"?>\n";
			$xmlOutput .= "<rss version=\"2.0\">\n";
			$xmlOutput .= "<channel>\n";
			$xmlOutput .= "<title>".$this->channelTitle."</title>\n";
			$xmlOutput .= "<description>".$this->channelDescription."</description>\n";
			$xmlOutput .= "<link>".$this->channelLink."</link>\n";
			$xmlOutput .= "<copyright>".$this->channelCopyright."</copyright>\n";
			$xmlOutput .= "<webMaster>".$this->channelWebMaster."</webMaster>\n";
			$xmlOutput .= "<generator>".$this->channelGenerator."</generator>\n";
			$xmlOutput .= "<lastBuildDate>".date('r',time())."</lastBuildDate>\n";
			$xmlOutput .= "<language>".$this->channelLanguage."</language>\n";
		
			$db->query("SELECT n.id AS docId, 
			                   n.date, 
			                   n.title, 
			                   n.text,
			                   n.source,
			                   u.firstname, 
			                   u.lastname,
			                   n.lang,
			                   n.userid, 
			                   u.id
						FROM ".DBPREFIX."module_docsys AS n,
			                 ".DBPREFIX."access_users AS u
						WHERE n.userid = u.id AND n.lang = ".$_LANGID."
						ORDER BY n.id DESC 
						LIMIT ".$this->limit);
								
			while ($db->next_record()){
				$xmlOutput .= "<item>\n";
				$xmlOutput .= "<title>".strip_tags(stripslashes($db->f('title')))."</title>\n";
				
				if ($this->xmlType == 'fulltext'){
					$xmlOutput .= "<description>".htmlspecialchars(stripslashes($db->f('text')))."</description>\n";
					//$xmlOutput .= "<description>".$db->f('text')."</description>";
					$xmlOutput .= "<source>".htmlspecialchars(stripslashes($db->f('source')))."</source>\n";
				}
				
				$xmlOutput .= "<pubDate>".date('r',time())."</pubDate>\n";
				$xmlOutput .= "<link>".$this->itemLink.$db->f('docId')."</link>\n";
				$xmlOutput .= "</item>\n";
			}
			$xmlOutput .= "</channel>\n";						
			$xmlOutput .= "</rss>";
			
			if ($this->xmlType == 'fulltext'){
				$fileHandle = @fopen(ASCMS_DOCUMENT_ROOT.$this->filePath.$this->fileName[2],"w+");
			}else {
				$fileHandle = @fopen(ASCMS_DOCUMENT_ROOT.$this->filePath.$this->fileName[1],"w+");
			}			
			if($fileHandle){
				@fwrite($fileHandle,$xmlOutput);
				@fclose($fileHandle);
			}
    	}
    }
}
?>